@@ -48,25 +48,25 @@ import constructs
 @jsii.data_type(
     jsii_type="@aws-prototyping-sdk/static-website.CidrAllowList",
     jsii_struct_bases=[],
-    name_mapping={"cidr_ranges": "cidrRanges", "type": "type"},
+    name_mapping={"cidr_ranges": "cidrRanges", "cidr_type": "cidrType"},
 )
 class CidrAllowList:
     def __init__(
         self,
         *,
         cidr_ranges: typing.Sequence[builtins.str],
-        type: builtins.str,
+        cidr_type: builtins.str,
     ) -> None:
         '''(experimental) Representation of a CIDR range.
 
         :param cidr_ranges: (experimental) Specify an IPv4 address by using CIDR notation. For example: To configure AWS WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify 192.0.2.44/32 . To configure AWS WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24 . For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing . Specify an IPv6 address by using CIDR notation. For example: To configure AWS WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128 . To configure AWS WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64 .
-        :param type: (experimental) Type of CIDR range.
+        :param cidr_type: (experimental) Type of CIDR range.
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "cidr_ranges": cidr_ranges,
-            "type": type,
+            "cidr_type": cidr_type,
         }
 
     @builtins.property
@@ -90,13 +90,13 @@ class CidrAllowList:
         return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
-    def type(self) -> builtins.str:
+    def cidr_type(self) -> builtins.str:
         '''(experimental) Type of CIDR range.
 
         :stability: experimental
         '''
-        result = self._values.get("type")
-        assert result is not None, "Required property 'type' is missing"
+        result = self._values.get("cidr_type")
+        assert result is not None, "Required property 'cidr_type' is missing"
         return typing.cast(builtins.str, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
